@@ -349,4 +349,7 @@ def write_excel_for_template(value: dict, wb_tmp: Workbook, *args, **kwargs) ->
             wst.active_source_sheet = source
             wb_tmp.remove(source)
             wst.write_sheet(source, obj_value, target)
-            target.title = sheet_name
+            if obj_value.get("sheet_name", ""):
+                target.title = obj_value["sheet_name"]
+            else:
+                target.title = sheet_name
\ No newline at end of file
